geowatch.tasks.cold.export\_cold\_result\_kwcoco module
=======================================================

.. automodule:: geowatch.tasks.cold.export_cold_result_kwcoco
   :members:
   :undoc-members:
   :show-inheritance:
